@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 本月免费额度已用完，如需继续使用您可以在机器翻译控制台升级为付费使用。
 FAILEDOPERATION_NOFREEAMOUNT = 'FailedOperation.NoFreeAmount'
 
@@ -41,12 +44,18 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 重复的SessionUuid和Seq组合。
 INVALIDPARAMETER_DUPLICATEDSESSIONIDANDSEQ = 'InvalidParameter.DuplicatedSessionIdAndSeq'
 
+# 参数错误。
+INVALIDPARAMETER_MISSINGPARAMETER = 'InvalidParameter.MissingParameter'
+
 # Seq之间的间隙请不要大于2000。
 INVALIDPARAMETER_SEQINTERVALTOOLARGE = 'InvalidParameter.SeqIntervalTooLarge'
 
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 超出请求频率。
+LIMITEXCEEDED_LIMITEDACCESSFREQUENCY = 'LimitExceeded.LimitedAccessFrequency'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
